package com.zhyc.module.produce.breed.service;

import java.util.List;
import java.util.Map;
import com.zhyc.module.produce.breed.domain.ScPregnancyRecord;

/**
 * 孕检记录Service接口
 *
 * @author zhyc
 * @date 2025-01-21
 */
public interface IScPregnancyRecordService
{
    /**
     * 查询孕检记录
     *
     * @param id 孕检记录主键
     * @return 孕检记录
     */
    public ScPregnancyRecord selectScPregnancyRecordById(Long id);

    /**
     * 查询孕检记录列表
     *
     * @param scPregnancyRecord 孕检记录
     * @return 孕检记录集合
     */
    public List<ScPregnancyRecord> selectScPregnancyRecordList(ScPregnancyRecord scPregnancyRecord);

    /**
     * 新增孕检记录
     *
     * @param scPregnancyRecord 孕检记录
     * @return 结果
     */
    public int insertScPregnancyRecord(ScPregnancyRecord scPregnancyRecord);

    /**
     * 修改孕检记录
     *
     * @param scPregnancyRecord 孕检记录
     * @return 结果
     */
    public int updateScPregnancyRecord(ScPregnancyRecord scPregnancyRecord);

    /**
     * 批量删除孕检记录
     *
     * @param ids 需要删除的孕检记录主键集合
     * @return 结果
     */
    public int deleteScPregnancyRecordByIds(Long[] ids);

    /**
     * 删除孕检记录信息
     *
     * @param id 孕检记录主键
     * @return 结果
     */
    public int deleteScPregnancyRecordById(Long id);

    /**
     * 根据耳号查询羊只信息
     *
     * @param manageTags 耳号
     * @return 羊只信息
     */
    public Map<String, Object> getSheepByManageTags(String manageTags);

    /**
     * 根据耳号获取配种信息
     *
     * @param manageTags 耳号
     * @return 配种信息
     */
    public Map<String, Object> getBreedInfoByManageTags(String manageTags);
    /**
     * 模糊查询母羊耳号列表
     *
     * @param query 查询关键字
     * @return 耳号列表
     */
    public List<String> searchEarNumbers(String query);
}